@@ -1,10 +1,12 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.009-5-g5e9cdca
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.010-11-g3cc61ca
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
-# vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.010';
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.011';
+
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
@@ -17,7 +19,7 @@ use Moose::Util::TypeConstraints 'enum';
 use Unicode::Collate 0.53;
 use namespace::autoclean;
 
-sub mvp_multivalue_args { qw(paths) }
+sub mvp_multivalue_args { qw(paths remove) }
 sub mvp_aliases { return { path => 'paths' } }
 
 has include_authors => (
@@ -43,6 +45,14 @@ has paths => (
     handles => { paths => 'elements' },
 );
 
+has remove => (
+    isa => 'ArrayRef[Str]',
+    lazy => 1,
+    default => sub { [] },
+    traits => ['Array'],
+    handles => { remove => 'elements' },
+);
+
 around dump_config => sub
 {
     my ($orig, $self) = @_;
@@ -55,6 +65,7 @@ around dump_config => sub
         include_releaser  => $self->include_releaser,
         order_by => $self->order_by,
         paths => [ @paths == 1 ? () : @paths ],
+        $self->remove ? ( remove => '...' ) : (),
     };
 
     return $config;
@@ -119,6 +130,13 @@ sub _contributors
         @contributors = grep { $_ ne $releaser } @contributors;
     }
 
+    if ($self->remove)
+    {
+        @contributors = grep {
+            my $contributor = $_; none { $contributor =~ /$_/ } $self->remove
+        } @contributors;
+    }
+
     return \@contributors;
 }
 
@@ -176,7 +194,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -220,11 +238,20 @@ commits made to the repository (descending). The default value is C<name>.
 
 =head2 C<path>
 
+Available since version 0.007.
+
 Indicates a path, relative to the repository root, to search for commits in.
 Technically: "Consider only commits that are enough to explain how the files that match the specified paths came to be."
 Defaults to the repository root. Can be used more than once.
 I<You should almost certainly not need this.>
 
+=head2 C<remove>
+
+Available since version 0.011.
+
+Any contributor entry matching this regular expression is removed from inclusion.
+Can be used more than once.
+
 =for stopwords canonicalizing
 
 =head1 CANONICALIZING NAMES AND ADDRESSES
